;; Generated package description from inspector.el  -*- no-byte-compile: t -*-
(define-package "inspector" "0.29.0.20230501.105318" "Tool for inspection of Emacs Lisp objects" '((emacs "27.1")) :commit "c328475aa433a39dd08702ff7daf5941a3a3efde" :authors '(("Mariano Montone" . "marianomontone@gmail.com")) :maintainer '("Mariano Montone" . "marianomontone@gmail.com") :keywords '("debugging" "tool" "lisp" "development") :url "https://github.com/mmontone/emacs-inspector")
